@@ -6,12 +6,14 @@ from ftw.table import helper
 
 class IndexTab(IndexView):
     """Index Tab (for tabbed_view)"""
-    show_searchform = False
+
+    def get_css_classes(self):
+        return ['searchform-hidden']
 
 
 class DocumentsTab(CatalogListingView):
 
-    types = 'File'
+    types = ['ftw.file.File', 'Image']
     sort_on = 'created'
     show_selects = False
     show_menu = False
@@ -20,7 +22,7 @@ class DocumentsTab(CatalogListingView):
                 'column_title': _(u'column_title', default=u'Title'),
                 'sort_index': 'sortable_title',
                 'transform': helper.linked},
-               {'column': 'effective',
+               {'column': 'documentDate',
                 'column_title': _(u'column_date', default=u'date'),
                 'transform': helper.readable_date},
                {'column': 'Creator',
